@@ -102,7 +102,7 @@ class Make_panpipe(make.Make):
         self.log.log('Min wall thickness: %.1fmm\n' % pad)
         self.log.log('Hole diameter: %.1fmm\n' % diameter)
         
-        holes = [ ]
+        negatives = [ ]
         lengths = [ ]
         xs = [ ]
         for i, note in enumerate(SCALE):
@@ -113,9 +113,10 @@ class Make_panpipe(make.Make):
             xs.append(x)
             hole = make_hole(diameter, length)
             hole.move(x,0,0)
-            holes.append(hole)
+            negatives.append(hole)
         
-        string_hole_loop = shape.circle(diameter*1.5)
+        string_hole_diameter = diameter*1.5
+        string_hole_loop = shape.circle(string_hole_diameter)
         string_hole = shape.extrusion([-zsize,zsize],[string_hole_loop,string_hole_loop])
         string_hole.rotate(1,0,0, 90)
         
@@ -131,11 +132,31 @@ class Make_panpipe(make.Make):
         #string_x = (xmid+xhigh)*0.5 - diameter
         #string_z = (zmid+zhigh)*0.5 - diameter
         #string_z = lengths[3] + diameter*2
-        string_x = xhigh-trim*0.5-diameter
-        string_z = zhigh-trim*0.5-diameter
+        #string_x = xhigh-trim*0.5-diameter
+        #string_z = zhigh-trim*0.5-diameter
+        
+        a = math.pi*-5/8
+        d = diameter * 1.5
+        string_x = xhigh-trim + math.cos(a)*d
+        string_z = zhigh      + math.sin(a)*d
         
         string_hole.move(string_x,0,string_z)
         
+        #p = pad*0.5
+        #loop = shape.Loop([(0,p),(p*2,-p),(-p*2,p)])
+        #r = diameter-pad
+        #stick = shape.extrusion([-r,r],[loop,loop])
+        #
+        #for i in xrange(-1,len(SCALE)+2):
+        #    for j in xrange(int(zhigh / (diameter+pad))+1):
+        #        x = (i-0.5)*(diameter+pad)
+        #        z = r + j*(diameter+pad)
+        #        c = stick.copy()
+        #        if (i^j)&1:
+        #            c.rotate(0,1,0,90)
+        #        c.move(x,-diameter*0.5-pad,z)
+        #        negatives.append(c)
+        
         loop = shape.Loop([
             (xlow,0),
             (xhigh,0),
@@ -171,11 +192,11 @@ class Make_panpipe(make.Make):
         positive.rotate(1,0,0,90)
         
         negative = string_hole.copy()
-        for i, hole in enumerate(holes):
-            print 'Merge hole %d / %d' % (i+1,len(holes))
-            negative.add(hole)
+        for i, item in enumerate(negatives):
+            print 'Merge %d / %d' % (i+1,len(negatives))
+            negative.add(item)
         
-        del holes
+        del negatives
         
         instrument = positive.copy()
         
@@ -189,9 +210,11 @@ class Make_panpipe(make.Make):
         extent = instrument.extent()
 
         copy = instrument.copy()
-        copy.move(-(extent.xmin+extent.xmax)*0.5,
-                  -(extent.ymin+extent.ymax)*0.5,
-                  -extent.zmin)
+        copy.rotate(0,0,1,-45)
+        cextent = copy.extent()
+        copy.move(-(cextent.xmin+cextent.xmax)*0.5,
+                  -(cextent.ymin+cextent.ymax)*0.5,
+                  -cextent.zmin)
         self.save(copy,'instrument')
         del copy
         
